@@ -1,6 +1,6 @@
 /* This file is part of GNU Radius.
    Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2007 Free Software Foundation, Inc.
+   2007,2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -341,10 +341,6 @@ extern unsigned long stat_start_time;
 extern REQUEST_CLASS    request_class[];
 extern int max_threads;
 extern int num_threads;
-#ifdef USE_SERVER_GUILE
-extern unsigned scheme_gc_interval;
-extern u_int scheme_task_timeout;
-#endif
 #ifdef USE_SNMP
 extern int snmp_port;
 extern char *server_id;
@@ -703,10 +699,14 @@ typedef struct channel Channel;
 
 struct channel {
         char *name;
-        int  pmask[L_NCAT]; 
+        int  pmask[GRAD_LOG_NCAT]; 
         int mode;   /* LM_ constant */
         union {
-                int prio;        /* syslog: facility|priority */
+		struct {
+			int prio;   /* syslog priority */
+			int fac;    /* syslog facility */
+			char *tag;  /* syslog tag */
+		} sl;
                 char *file;      /* file: output file name */
         } id;
         int options;
@@ -745,8 +745,8 @@ void radiusd_sql_cleanup(int type, void *req);
 char *radiusd_sql_pass(radiusd_request_t *req, char *data);
 
 # ifdef RADIUS_SERVER_GUILE
-SCM sql_exec_query(int type, char *query);
-SCM sql_run_query(int type, char *query);
+SCM sql_exec_query(int type, const char *query);
+SCM sql_run_query(int type, const char *query);
 # endif
 
 #else
