@@ -1,12 +1,12 @@
 /* This file is part of GNU Radius.
    Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2006 Free Software Foundation, Inc.
+   2006,2007,2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
  
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
  
    GNU Radius is distributed in the hope that it will be useful,
@@ -35,7 +35,7 @@
 #include <errno.h>
 #include <ctype.h>
 
-#include <common.h>
+#include <radlib.h>
 
 void
 grad_client_random_authenticator(char *authenticator)
@@ -110,8 +110,8 @@ grad_client_message_id(grad_server_t *server)
 }
 	
 grad_request_t *
-grad_client_recv(grad_uint32_t host, u_short udp_port, char *secret, char *authenticator,
-	     char *buffer, int length)
+grad_client_recv(grad_uint32_t host, u_short udp_port, char *secret,
+		 char *authenticator, char *buffer, int length)
 {
         grad_packet_header_t *auth;
         int totallen;
@@ -124,7 +124,7 @@ grad_client_recv(grad_uint32_t host, u_short udp_port, char *secret, char *authe
         totallen = ntohs(auth->length);
 
         if (totallen != length) {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
            _("Actual request length does not match reported length (%d, %d)"),
                          totallen, length);
                 return NULL;
@@ -137,9 +137,9 @@ grad_client_recv(grad_uint32_t host, u_short udp_port, char *secret, char *authe
         memcpy(buffer + length, secret, secretlen);
         grad_md5_calc(calc_digest, (unsigned char *)auth, length + secretlen);
         
-	GRAD_DEBUG(1, ("received %s", grad_request_code_to_name(auth->code)));
+	GRAD_DEBUG1(1, "received %s", grad_request_code_to_name(auth->code));
         if (memcmp(reply_digest, calc_digest, GRAD_AUTHENTICATOR_LENGTH) != 0) {
-                grad_log(L_WARN, _("Received invalid reply digest from server"));
+                grad_log(GRAD_LOG_WARN, _("Received invalid reply digest from server"));
         }
 
         req = grad_decode_pdu(host, udp_port, buffer, length);
@@ -196,6 +196,38 @@ grad_client_decrypt_pairlist(grad_avp_t *plist, u_char *authenticator, u_char *s
 	return plist;
 }
 
+static int
+wait_for_reply(int fd, unsigned timeout)
+{
+	fd_set readfds;
+	struct timeval start, tm;
+	
+	gettimeofday(&start, NULL);
+
+	for (;;) {
+		tm.tv_usec = 0L;
+		tm.tv_sec = (long) timeout;
+
+		FD_ZERO(&readfds);
+		FD_SET(fd, &readfds);
+		if (grad_recompute_timeout (&start, &tm)) 
+			return 0;
+
+		if (select(fd+1, &readfds, NULL, NULL, &tm) < 0) {
+			if (errno == EINTR) {
+				GRAD_DEBUG(20,
+					   "select interrupted. retrying.");
+				continue;
+			}
+			grad_log(GRAD_LOG_NOTICE, _("select() interrupted"));
+			break;
+		}
+
+		return FD_ISSET (fd, &readfds);
+	}
+	return 1;
+}
+
 grad_request_t *
 grad_client_send0(grad_server_queue_t *config, int port_type, int code,
 		  grad_avp_t *pairlist,
@@ -205,7 +237,6 @@ grad_client_send0(grad_server_queue_t *config, int port_type, int code,
 	struct sockaddr salocal;
 	struct sockaddr saremote;
 	struct sockaddr_in *sin;
-        int local_port;
         int sockfd;
         int salen;
         int i;
@@ -217,12 +248,12 @@ grad_client_send0(grad_server_queue_t *config, int port_type, int code,
 	int id;
 	
         if (port_type < 0 || port_type > 2) {
-                grad_log(L_ERR, _("invalid port type"));
+                grad_log(GRAD_LOG_ERR, _("invalid port type"));
                 return NULL;
         }
         sockfd = socket(PF_INET, SOCK_DGRAM, 0);
         if (sockfd < 0) {
-                grad_log(L_ERR|L_PERROR, "socket");
+                grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR, "socket");
                 return NULL;
         }
 
@@ -231,28 +262,18 @@ grad_client_send0(grad_server_queue_t *config, int port_type, int code,
         sin->sin_family = AF_INET;
         sin->sin_addr.s_addr = config->source_ip ?
                                    htonl(config->source_ip) : INADDR_ANY;
-
-	/*FIXME: not necessary?*/
-        local_port = 1025;
-        do {
-                local_port++;
-                sin->sin_port = htons((u_short)local_port);
-        } while ((bind(sockfd, &salocal, sizeof (struct sockaddr_in)) < 0)
-		 && local_port < 65535);
-        if (local_port >= 65535) {
-                grad_log(L_ERR|L_PERROR, "bind");
+        sin->sin_port = 0;
+        if (bind(sockfd, &salocal, sizeof (struct sockaddr_in))) {
+                grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR, "bind");
                 close(sockfd);
                 return NULL;
         }
 
-	GRAD_DEBUG(1,
-	      ("sending %s", grad_request_code_to_name(code)));
+	GRAD_DEBUG1(1, "sending %s", grad_request_code_to_name(code));
 	recv_buf = grad_emalloc(config->buffer_size);
         itr = grad_iterator_create(config->servers);
         server = grad_iterator_first(itr);
         do {
-		fd_set readfds;
-		struct timeval tm;
 		int result;
 		u_char authenticator[GRAD_AUTHENTICATOR_LENGTH];
 		void *pdu;
@@ -262,11 +283,9 @@ grad_client_send0(grad_server_queue_t *config, int port_type, int code,
                 if (server->port[port_type] <= 0)
                         continue;
                 
-                if (GRAD_DEBUG_LEVEL(10)) {
-                        grad_log(L_DEBUG, "server %s:%d",
+                GRAD_DEBUG2(10, "server %s:%d",
                                  grad_ip_iptostr(server->addr, ipbuf),
                                  server->port[port_type]);
-                }
 
                 if (authid && (flags & RADCLT_AUTHENTICATOR))
 			memcpy(authenticator, authvec, sizeof authenticator);
@@ -277,7 +296,8 @@ grad_client_send0(grad_server_queue_t *config, int port_type, int code,
 		else
 			id = grad_client_message_id(server);
 		pair = grad_client_encrypt_pairlist(grad_avl_dup(pairlist),
-						    authenticator, server->secret);
+						    authenticator,
+						    server->secret);
 		size = grad_create_pdu(&pdu, code,
 				       id,
 				       authenticator,
@@ -302,31 +322,22 @@ grad_client_send0(grad_server_queue_t *config, int port_type, int code,
                 sin->sin_addr.s_addr = htonl(server->addr);
                 sin->sin_port = htons(server->port[port_type]);
 
+		GRAD_DEBUG2(10, "sending request (timeout=%u, retries=%u)",
+			    config->timeout, config->retries);
+		
                 for (i = 0; i < config->retries; i++) {
-                        if (sendto(sockfd, pdu, size, 0,
+			if (i)
+				GRAD_DEBUG(10,"no response. retrying.");
+				
+			if (sendto(sockfd, pdu, size, 0,
                                    &saremote,
                                    sizeof(struct sockaddr_in)) == -1) {
-                                grad_log(L_ERR|L_PERROR, "sendto");
+                                grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR, "sendto");
                         }
 
                         salen = sizeof (saremote);
 
-                        tm.tv_usec = 0L;
-                        tm.tv_sec = (long) config->timeout;
-                        FD_ZERO(&readfds);
-                        FD_SET(sockfd, &readfds);
-                        if (select(sockfd+1, &readfds, NULL, NULL, &tm) < 0) {
-                                if (errno == EINTR) {
-                                        i--;
-					GRAD_DEBUG(20,
-					      ("select interrupted. retrying."));
-                                        continue;
-                                }
-                                grad_log(L_NOTICE, _("select() interrupted"));
-                                break;
-                        }
-
-                        if (FD_ISSET (sockfd, &readfds)) {
+                        if (wait_for_reply (sockfd, config->timeout)) {
                                 result = recvfrom(sockfd,
                                                   recv_buf,
                                                   config->buffer_size,
@@ -341,22 +352,21 @@ grad_client_send0(grad_server_queue_t *config, int port_type, int code,
                                                 recv_buf,
                                                 result);
                                 else 
-                                        grad_log(L_ERR|L_PERROR,
+                                        grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR,
                                         _("error receiving data from %s:%d"),
                                                  grad_ip_iptostr(server->addr, ipbuf),
                                                  server->port[port_type]);
                                 
                                 break;
                         }
-			GRAD_DEBUG(10,("no response. retrying."));
                 }
 		
 		grad_free(pdu);
 		
                 if (!req)
-                        GRAD_DEBUG(10,("no reply from %s:%d",
-				  grad_ip_iptostr(server->addr, ipbuf),
-				  server->port[port_type]));
+                        GRAD_DEBUG2(10,"no reply from %s:%d",
+				    grad_ip_iptostr(server->addr, ipbuf),
+				    server->port[port_type]);
 		
         } while (!req && (server = grad_iterator_next(itr)) != NULL);
 	grad_iterator_destroy(&itr);
@@ -381,6 +391,7 @@ grad_client_send(grad_server_queue_t *config, int port_type, int code,
 #define TOK_SERVER     2
 #define TOK_TIMEOUT    3
 #define TOK_RETRY      4
+#define TOK_DEBUG      5
 
 static grad_keyword_t kwd[] = {
         { "source_ip", TOK_SOURCE_IP },
@@ -388,6 +399,7 @@ static grad_keyword_t kwd[] = {
         { "server", TOK_SERVER },
         { "timeout", TOK_TIMEOUT },
         { "retry", TOK_RETRY },
+	{ "debug", TOK_DEBUG },
         { NULL }
 };
 
@@ -397,10 +409,11 @@ parse_client_config(void *closure, int argc, char **argv, grad_locus_t *loc)
 	grad_server_queue_t *client = closure;
         char *p;
         grad_server_t serv;
-        
+	int i;
+	
         switch (grad_xlat_keyword(kwd, argv[0], TOK_INVALID)) {
         case TOK_INVALID:
-                grad_log_loc(L_ERR, loc, _("unknown keyword"));
+                grad_log_loc(GRAD_LOG_ERR, loc, _("unknown keyword"));
                 break;
                 
         case TOK_SOURCE_IP:
@@ -409,7 +422,7 @@ parse_client_config(void *closure, int argc, char **argv, grad_locus_t *loc)
                 
         case TOK_SERVER:
                 if (argc != 6) {
-                        grad_log_loc(L_ERR, loc, _("wrong number of fields"));
+                        grad_log_loc(GRAD_LOG_ERR, loc, _("wrong number of fields"));
                         break;
                 }
                 memset(&serv, 0, sizeof serv);
@@ -417,7 +430,7 @@ parse_client_config(void *closure, int argc, char **argv, grad_locus_t *loc)
                 serv.name = argv[1];
                 serv.addr = grad_ip_gethostaddr(argv[2]);
                 if (!serv.addr) {
-                        grad_log_loc(L_ERR, loc,
+                        grad_log_loc(GRAD_LOG_ERR, loc,
 				     _("bad IP address or host name"));
                         break;
                 }
@@ -426,14 +439,14 @@ parse_client_config(void *closure, int argc, char **argv, grad_locus_t *loc)
 
                 serv.port[0] = strtol(argv[4], &p, 0);
                 if (*p) {
-                        grad_log_loc(L_ERR, loc, _("bad port number %s"),
+                        grad_log_loc(GRAD_LOG_ERR, loc, _("bad port number %s"),
 				     argv[4]);
                         break;
                 }
 
                 serv.port[1] = strtol(argv[5], &p, 0);
                 if (*p) {
-                        grad_log_loc(L_ERR, loc, _("bad port number %s"),
+                        grad_log_loc(GRAD_LOG_ERR, loc, _("bad port number %s"),
 				     argv[4]);
                         break;
                 }
@@ -445,14 +458,19 @@ parse_client_config(void *closure, int argc, char **argv, grad_locus_t *loc)
         case TOK_TIMEOUT:
                 client->timeout = strtol(argv[1], &p, 0);
                 if (*p) 
-                        grad_log_loc(L_ERR, loc,  _("bad timeout value"));
+                        grad_log_loc(GRAD_LOG_ERR, loc,  _("bad timeout value"));
                 break;
                 
         case TOK_RETRY:
                 client->retries = strtol(argv[1], &p, 0);
                 if (*p) 
-                        grad_log_loc(L_ERR, loc, _("bad retry value"));
+                        grad_log_loc(GRAD_LOG_ERR, loc, _("bad retry value"));
                 break;
+
+	case TOK_DEBUG:
+		for (i = 1; i < argc; i++)
+			grad_set_debug_levels(argv[i]);
+		break;
         }
         return 0;
 }
