@@ -1,11 +1,12 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2005,
+   2007 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -13,16 +14,17 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software Foundation,
-   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+   You should have received a copy of the GNU General Public
+   License along with GNU Radius; if not, write to the Free
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 #include <stdlib.h>
 #include <string.h>
-#include <common.h>
+#include <radlib.h>
 
 typedef struct envar {
         char *name;
@@ -73,7 +75,7 @@ grad_envar_assign(char *name, char *value, grad_list_t **plist)
 
 
 static void
-grad_envar_parse_argcv_internal(int argc, char **argv, grad_list_t **plist)
+grad_envar_parse_grad_argcv_internal(int argc, char **argv, grad_list_t **plist)
 {
 	int i;
 	char *p;
@@ -83,7 +85,7 @@ grad_envar_parse_argcv_internal(int argc, char **argv, grad_list_t **plist)
                         continue;
                 p = strchr(argv[i], '=');
                 if (p) 
-			grad_envar_assign_internal(p, p - argv[i],
+			grad_envar_assign_internal(argv[i], p - argv[i],
 						   p + 1, strlen(p + 1),
 						   plist);
 		else
@@ -99,13 +101,13 @@ grad_envar_parse_internal(char *str, grad_list_t **plist)
         int argc;
         char **argv;
 
-        if (argcv_get(str, ",", NULL, &argc, &argv)) {
+        if (grad_argcv_get(str, ",", NULL, &argc, &argv)) {
                 if (argv)
-                        argcv_free(argc, argv);
+                        grad_argcv_free(argc, argv);
                 return;
         }
-	grad_envar_parse_argcv_internal(argc, argv, plist);
-	argcv_free(argc, argv);
+	grad_envar_parse_grad_argcv_internal(argc, argv, plist);
+	grad_argcv_free(argc, argv);
 }
 
 grad_envar_t *
