@@ -1,5 +1,5 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2003,2004,2007 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2003,2004,2007,2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -35,7 +35,7 @@
 
 
 
-static grad_logger_fp _grad_logger;
+static grad_logger_fp _grad_logger = grad_default_logger;
 
 grad_logger_fp
 grad_set_logger(grad_logger_fp fp)
@@ -51,10 +51,11 @@ grad_log(int lvl, const char *msg, ...)
         va_list ap;
         int ec = 0;
 
-        if (lvl & L_PERROR)
+        if (lvl & GRAD_LOG_PERROR)
                 ec = errno;
         va_start(ap, msg);
-        _grad_logger(lvl, NULL, NULL, NULL, ec, msg, ap);
+	if (_grad_logger)
+		_grad_logger(lvl, NULL, NULL, NULL, ec, msg, ap);
         va_end(ap);
 }
 
@@ -64,10 +65,11 @@ grad_log_req(int lvl, grad_request_t *req, const char *msg, ...)
         va_list ap;
         int ec = 0;
 
-        if (lvl & L_PERROR)
+        if (lvl & GRAD_LOG_PERROR)
                 ec = errno;
         va_start(ap, msg);
-        _grad_logger(lvl, req, NULL, NULL, ec, msg, ap);
+	if (_grad_logger)
+		_grad_logger(lvl, req, NULL, NULL, ec, msg, ap);
         va_end(ap);
 }
 
@@ -77,10 +79,11 @@ grad_log_loc(int lvl, grad_locus_t *loc, const char *msg, ...)
 	va_list ap;
 	int ec = 0;
 
-	if (lvl & L_PERROR)
+	if (lvl & GRAD_LOG_PERROR)
 		ec = errno;
 
 	va_start(ap, msg);
-	_grad_logger(lvl, NULL, loc, NULL, ec, msg, ap);
+	if (_grad_logger)
+		_grad_logger(lvl, NULL, loc, NULL, ec, msg, ap);
 	va_end(ap);
 }
