@@ -1,9 +1,10 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2002, 2003, 2004 Free Software Foundation
+   Copyright (C) 2002, 2003, 2004, 2005, 2007,
+   2008 Free Software Foundation
   
    GNU Radius is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2 of the License, or
+   the Free Software Foundation; either version 3 of the License, or
    (at your option) any later version.
   
    GNU Radius is distributed in the hope that it will be useful,
@@ -11,23 +12,23 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
   
-   You should have received a copy of the GNU General Public License
-   along with GNU Radius; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-   MA 02111-1307, USA. */
+   You should have received a copy of the GNU General Public
+   License along with GNU Radius; if not, write to the Free
+   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA. */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
 #include <stdlib.h>
-#include <common.h>
+#include <radlib.h>
 
 static grad_list_t /* of grad_realm_t */ *realms; 
 
 struct _parse_data {
 	int (*fun)();
-	int ports[PORT_MAX];
+	int ports[GRAD_PORT_MAX];
 	grad_locus_t *loc;
 };
 
@@ -41,19 +42,19 @@ _parse_server(int argc, char **argv, struct _parse_data *pd, int *np,
 	if (*np+1 < argc && argv[*np][0] == ':') {
 		char *p;
 		
-                srv->port[PORT_AUTH] = strtoul(argv[++*np], &p, 0);
+                srv->port[GRAD_PORT_AUTH] = strtoul(argv[++*np], &p, 0);
 		if (*np+2 < argc && argv[*np+1][0] == ':') {
 			++*np;
-			srv->port[PORT_ACCT] = strtoul(argv[++*np], &p, 0);
+			srv->port[GRAD_PORT_ACCT] = strtoul(argv[++*np], &p, 0);
 		} else
-			srv->port[PORT_ACCT] = srv->port[PORT_AUTH] + 1;
+			srv->port[GRAD_PORT_ACCT] = srv->port[GRAD_PORT_AUTH] + 1;
 		++*np;
 	} else {
-		srv->port[PORT_AUTH] = pd->ports[PORT_AUTH];
-		srv->port[PORT_ACCT] = pd->ports[PORT_ACCT];
+		srv->port[GRAD_PORT_AUTH] = pd->ports[GRAD_PORT_AUTH];
+		srv->port[GRAD_PORT_ACCT] = pd->ports[GRAD_PORT_ACCT];
 	}
 	if (pd->fun && pd->fun(srv)) {
-		grad_log_loc(L_ERR, pd->loc,
+		grad_log_loc(GRAD_LOG_ERR, pd->loc,
 			     _("can't find secret for %s"),
 			     srv->name);
 		return 1; 
@@ -67,7 +68,7 @@ _parse_server_list(grad_server_queue_t *qp, char *str, struct _parse_data *pd)
 	int i, argc;
 	char **argv;
 
-	if (argcv_get(str, ",:", NULL, &argc, &argv)) 
+	if (grad_argcv_get(str, ",:", NULL, &argc, &argv)) 
 		return 1;
 
 	for (i = 0; i < argc; i++) {
@@ -77,14 +78,14 @@ _parse_server_list(grad_server_queue_t *qp, char *str, struct _parse_data *pd)
 					      grad_client_alloc_server(&srv));
 
 		if (i < argc && argv[i][0] != ',') {
-			grad_log_loc(L_ERR, pd->loc,
+			grad_log_loc(GRAD_LOG_ERR, pd->loc,
 				     _("expected , but found %s"),
 				     argv[i]);
-			argcv_free(argc, argv);
+			grad_argcv_free(argc, argv);
 			return 1;
 		}
 	}
-	argcv_free(argc, argv);
+	grad_argcv_free(argc, argv);
 	return 0;
 }
 
@@ -99,7 +100,7 @@ read_realms_entry(void *closure, int fc, char **fv, grad_locus_t *loc)
 	int i;
 	
         if (fc < 2) {
-                grad_log_loc(L_ERR, loc, _("too few fields (%d)"), fc);
+                grad_log_loc(GRAD_LOG_ERR, loc, _("too few fields (%d)"), fc);
                 return -1;
         }
 
@@ -121,7 +122,7 @@ read_realms_entry(void *closure, int fc, char **fv, grad_locus_t *loc)
 		i++;
 		
 		if (grad_list_count(rp->queue->servers) == 0) {
-			grad_log_loc(L_NOTICE, loc, _("discarding entry"));
+			grad_log_loc(GRAD_LOG_NOTICE, loc, _("discarding entry"));
 			grad_client_destroy_queue(rp->queue);
 			grad_free(rp);
 			return 0;
@@ -167,8 +168,8 @@ grad_read_realms(char *file, int auth_port, int acct_port, int (*set_secret)())
 	grad_list_destroy(&realms, _realm_mem_free, NULL);
         realms = NULL;
 	pd.fun = set_secret;
-	pd.ports[PORT_AUTH] = auth_port;
-	pd.ports[PORT_ACCT] = acct_port;
+	pd.ports[GRAD_PORT_AUTH] = auth_port;
+	pd.ports[GRAD_PORT_ACCT] = acct_port;
         return grad_read_raddb_file(file, 1, NULL, read_realms_entry, &pd);
 }
 
@@ -178,7 +179,7 @@ static int
 realm_match_name_p(const grad_realm_t *realm, const char *name)
 {
 	return (grad_envar_lookup_int(realm->args, "ignorecase", 0) ?
-		strcasecmp : strcmp) (realm->realm, name) == 0;
+		grad_c_strcasecmp : strcmp) (realm->realm, name) == 0;
 }
 
 /* Find a realm in the REALM list */
