@@ -97,7 +97,8 @@
 #line 1 "users.y"
 
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2007 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2007,
+   2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -172,7 +173,7 @@ extern int uyylex();
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 69 "users.y"
+#line 70 "users.y"
 {
         char *string;
         grad_matching_rule_t *rule;
@@ -183,7 +184,7 @@ typedef union YYSTYPE
         enum grad_operator op;
 }
 /* Line 187 of yacc.c.  */
-#line 187 "users_gram.c"
+#line 188 "users_gram.c"
 	YYSTYPE;
 # define uyystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -196,7 +197,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 200 "users_gram.c"
+#line 201 "users_gram.c"
 
 #ifdef short
 # undef short
@@ -485,9 +486,9 @@ static const uyytype_int8 uyyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const uyytype_uint8 uyyrline[] =
 {
-       0,    81,    81,    82,    85,    88,    89,    95,    99,   111,
-     117,   124,   128,   131,   132,   143,   147,   153,   157,   161,
-     165,   169,   173,   179,   180
+       0,    82,    82,    83,    86,    89,    90,    96,   100,   112,
+     118,   125,   129,   132,   133,   144,   148,   154,   158,   162,
+     166,   170,   174,   180,   181
 };
 #endif
 
@@ -1402,29 +1403,29 @@ uyyreduce:
   switch (uyyn)
     {
         case 4:
-#line 86 "users.y"
+#line 87 "users.y"
     {
            }
     break;
 
   case 6:
-#line 90 "users.y"
+#line 91 "users.y"
     {
                    grad_parser_lex_sync(); uyyerrok; uyyclearin;
            }
     break;
 
   case 7:
-#line 96 "users.y"
+#line 97 "users.y"
     {
                    add_entry(closure, &start_loc, (uyyvsp[(1) - (2)].string), (uyyvsp[(2) - (2)].descr).lhs, (uyyvsp[(2) - (2)].descr).rhs);
            }
     break;
 
   case 8:
-#line 100 "users.y"
+#line 101 "users.y"
     {
-                   grad_log(L_ERR, _("discarding user `%s'"), (uyyvsp[(1) - (2)].string));
+                   grad_log(GRAD_LOG_ERR, _("discarding user `%s'"), (uyyvsp[(1) - (2)].string));
                    if (grad_parser_lex_sync() <= 0)
 			   uyychar = 0; /* force end-of-file */
 		   else {
@@ -1435,14 +1436,14 @@ uyyreduce:
     break;
 
   case 9:
-#line 112 "users.y"
+#line 113 "users.y"
     {
 		   start_loc = grad_parser_source_locus;
            }
     break;
 
   case 10:
-#line 118 "users.y"
+#line 119 "users.y"
     {
                    (uyyval.descr).lhs = (uyyvsp[(1) - (2)].pair);
                    (uyyval.descr).rhs = (uyyvsp[(2) - (2)].pair);
@@ -1450,14 +1451,14 @@ uyyreduce:
     break;
 
   case 11:
-#line 125 "users.y"
+#line 126 "users.y"
     {
                    (uyyval.pair) = NULL;
            }
     break;
 
   case 14:
-#line 133 "users.y"
+#line 134 "users.y"
     {
                    if ((uyyvsp[(1) - (3)].pair)) {
                            if ((uyyvsp[(3) - (3)].pair)) 
@@ -1469,56 +1470,56 @@ uyyreduce:
     break;
 
   case 15:
-#line 144 "users.y"
+#line 145 "users.y"
     {
                    (uyyval.pair) = grad_create_pair0((uyyvsp[(1) - (3)].string), (uyyvsp[(2) - (3)].op), (uyyvsp[(3) - (3)].string));   
            }
     break;
 
   case 16:
-#line 148 "users.y"
+#line 149 "users.y"
     {
                    YYERROR;
            }
     break;
 
   case 17:
-#line 154 "users.y"
+#line 155 "users.y"
     {
                    (uyyval.op) = grad_operator_equal;
            }
     break;
 
   case 18:
-#line 158 "users.y"
+#line 159 "users.y"
     {
                    (uyyval.op) = grad_operator_less_than;
            }
     break;
 
   case 19:
-#line 162 "users.y"
+#line 163 "users.y"
     { 
                    (uyyval.op) = grad_operator_greater_than;
            }
     break;
 
   case 20:
-#line 166 "users.y"
+#line 167 "users.y"
     {
                    (uyyval.op) = grad_operator_not_equal;
            }
     break;
 
   case 21:
-#line 170 "users.y"
+#line 171 "users.y"
     {
                    (uyyval.op) = grad_operator_less_equal;
            }
     break;
 
   case 22:
-#line 174 "users.y"
+#line 175 "users.y"
     {
                    (uyyval.op) = grad_operator_greater_equal;
            }
@@ -1526,7 +1527,7 @@ uyyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1530 "users_gram.c"
+#line 1531 "users_gram.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", uyyr1[uyyn], &uyyval, &uyyloc);
@@ -1740,13 +1741,13 @@ uyyreturn:
 }
 
 
-#line 183 "users.y"
+#line 184 "users.y"
 
 
 int
 uyyerror(char *s)
 {
-	grad_log_loc(L_ERR, &grad_parser_source_locus, "%s", s);
+	grad_log_loc(GRAD_LOG_ERR, &grad_parser_source_locus, "%s", s);
 	return 0;
 }
 
@@ -1769,7 +1770,7 @@ grad_create_pair(grad_locus_t *loc, char *name,
         struct tm *tm, tms;
         
         if ((attr = grad_attr_name_to_dict(name)) == NULL) {
-                grad_log_loc(L_ERR, loc, _("unknown attribute `%s'"),
+                grad_log_loc(GRAD_LOG_ERR, loc, _("unknown attribute `%s'"),
 			     name);
                 return NULL;
         }
@@ -1797,7 +1798,7 @@ grad_create_pair(grad_locus_t *loc, char *name,
                 if (pair->attribute == DA_EXEC_PROGRAM ||
                     pair->attribute == DA_EXEC_PROGRAM_WAIT) {
                         if (valstr[0] != '/' && valstr[0] != '|') {
-                                grad_log_loc(L_ERR, loc,
+                                grad_log_loc(GRAD_LOG_ERR, loc,
 					     _("%s: not an absolute pathname"),
 					     name);
                                 grad_avp_free(pair);
@@ -1809,7 +1810,7 @@ grad_create_pair(grad_locus_t *loc, char *name,
                 pair->avp_strlength = strlen(pair->avp_strvalue);
 		
 		if (attr->parser && attr->parser(pair, &s)) {
-			grad_log_loc(L_ERR, loc,
+			grad_log_loc(GRAD_LOG_ERR, loc,
 				     "%s %s: %s",
 				     _("attribute"),
 				     pair->name, s);
@@ -1842,7 +1843,7 @@ grad_create_pair(grad_locus_t *loc, char *name,
 							    pair->attribute))
 			         == NULL) {
                         grad_avp_free(pair);
-                        grad_log_loc(L_ERR, loc,
+                        grad_log_loc(GRAD_LOG_ERR, loc,
 				_("value %s is not declared for attribute %s"),
 				     valstr, name);
                         return NULL;
@@ -1873,7 +1874,7 @@ grad_create_pair(grad_locus_t *loc, char *name,
 
 			if (x) {
 				char *s;
-				char buf[INT_STRLEN_BOUND(long)];
+				char buf[INT_BUFSIZE_BOUND(long)];
 				grad_longtostr(pair->avp_lvalue,
 					       buf, sizeof buf);
 				grad_astrcat(&s, buf, "+", "%{NAS-Port-Id}",
@@ -1890,7 +1891,7 @@ grad_create_pair(grad_locus_t *loc, char *name,
                 timeval = time(0);
                 tm = localtime_r(&timeval, &tms);
                 if (grad_parse_time_string(valstr, tm)) {
-                        grad_log_loc(L_ERR, loc, _("%s: can't parse date"),
+                        grad_log_loc(GRAD_LOG_ERR, loc, _("%s: can't parse date"),
 				     name);
                         grad_avp_free(pair);
                         return NULL;
@@ -1903,7 +1904,7 @@ grad_create_pair(grad_locus_t *loc, char *name,
                 break;
 
         default:
-                grad_log_loc(L_ERR, loc,
+                grad_log_loc(GRAD_LOG_ERR, loc,
 			     _("%s: unknown attribute type %d"),
 			     name, pair->type);
                 grad_avp_free(pair);
@@ -1935,7 +1936,7 @@ void
 grad_enable_rule_debug(int val)
 {
         uyydebug = val;
-	grad_log_loc(L_NOTICE, &grad_parser_source_locus,
+	grad_log_loc(GRAD_LOG_NOTICE, &grad_parser_source_locus,
 		     uyydebug ? _("enabled userfile parser debugging") :
              	 	       _("disabled userfile parser debugging"));
 }
