@@ -91,7 +91,8 @@
 #line 1 "config.y"
 
 /* This file is part of GNU Radius.
-   Copyright (C) 2000,2001,2002,2003,2004,2007 Free Software Foundation, Inc.
+   Copyright (C) 2000,2001,2002,2003,2004,2007,
+   2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
 
@@ -156,7 +157,9 @@ static char *typestr[] = {
 	"ipaddr",
 	"port",
 	"char",
-	"host"
+	"host",
+	"unsigned",
+	"size"
 };
 	 
 struct syntax_block {
@@ -205,7 +208,7 @@ static char *curp;
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 97 "config.y"
+#line 100 "config.y"
 {
         size_t number;
         int bool;
@@ -217,7 +220,7 @@ typedef union YYSTYPE
 	struct cfg_stmt *stmt;
 }
 /* Line 187 of yacc.c.  */
-#line 221 "config.c"
+#line 224 "config.c"
 	YYSTYPE;
 # define ccstype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -230,7 +233,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 234 "config.c"
+#line 237 "config.c"
 
 #ifdef short
 # undef short
@@ -523,10 +526,10 @@ static const cctype_int8 ccrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const cctype_uint16 ccrline[] =
 {
-       0,   122,   122,   125,   126,   129,   130,   133,   134,   135,
-     141,   142,   145,   148,   177,   185,   188,   191,   215,   219,
-     224,   231,   237,   242,   247,   252,   257,   262,   267,   275,
-     280,   287,   294,   295
+       0,   125,   125,   128,   129,   132,   133,   136,   137,   138,
+     144,   145,   148,   151,   180,   188,   191,   194,   218,   222,
+     227,   234,   240,   245,   250,   255,   260,   265,   270,   278,
+     283,   290,   297,   298
 };
 #endif
 
@@ -1455,14 +1458,14 @@ ccreduce:
   switch (ccn)
     {
         case 9:
-#line 136 "config.y"
+#line 139 "config.y"
     {
 		      ccclearin; ccerrok;
 	      }
     break;
 
   case 13:
-#line 149 "config.y"
+#line 152 "config.y"
     {
 		      if ((ccvsp[(1) - (3)].stmt) && (ccvsp[(1) - (3)].stmt)->type == CS_BLOCK) {
 			      if ((ccvsp[(1) - (3)].stmt)->handler) {
@@ -1481,7 +1484,7 @@ ccreduce:
 			      _cfg_push_block((ccvsp[(1) - (3)].stmt)->block, (ccvsp[(1) - (3)].stmt)->end, (ccvsp[(1) - (3)].stmt)->data);
 		      } else {
 			      if (block->stmt) {
-				      grad_log(L_ERR,
+				      grad_log(GRAD_LOG_ERR,
 					       "%s:%d: %s",
 					       cfg_filename, cfg_line_num,
 					       _("unknown block statement"));
@@ -1492,7 +1495,7 @@ ccreduce:
     break;
 
   case 14:
-#line 178 "config.y"
+#line 181 "config.y"
     {
 		      if (block->prev)
 			      _cfg_pop_block();
@@ -1500,14 +1503,14 @@ ccreduce:
     break;
 
   case 15:
-#line 185 "config.y"
+#line 188 "config.y"
     {
 		      (ccval.vlist) = NULL;
 	      }
     break;
 
   case 17:
-#line 192 "config.y"
+#line 195 "config.y"
     {
 		      if ((ccvsp[(1) - (3)].stmt)) {
 			      if ((ccvsp[(1) - (3)].stmt)->handler) {
@@ -1524,7 +1527,7 @@ ccreduce:
 					      ccerror("syntax error");
 			      }
 		      } else if (block->stmt)
-			      grad_log(L_ERR,
+			      grad_log(GRAD_LOG_ERR,
 				       "%s:%d: %s",
 				       cfg_filename, cfg_line_num,
 				       _("unknown keyword"));
@@ -1532,14 +1535,14 @@ ccreduce:
     break;
 
   case 18:
-#line 216 "config.y"
+#line 219 "config.y"
     {
 		      (ccval.vlist) = _cfg_vlist_create(&(ccvsp[(1) - (1)].value));
 	      }
     break;
 
   case 19:
-#line 220 "config.y"
+#line 223 "config.y"
     {
 		      _cfg_vlist_append((ccvsp[(1) - (2)].vlist), &(ccvsp[(2) - (2)].value));
 		      (ccval.vlist) = (ccvsp[(1) - (2)].vlist);
@@ -1547,7 +1550,7 @@ ccreduce:
     break;
 
   case 20:
-#line 225 "config.y"
+#line 228 "config.y"
     {
 		      _cfg_vlist_append((ccvsp[(1) - (3)].vlist), &(ccvsp[(3) - (3)].value));
 		      (ccval.vlist) = (ccvsp[(1) - (3)].vlist);
@@ -1555,14 +1558,14 @@ ccreduce:
     break;
 
   case 21:
-#line 232 "config.y"
+#line 235 "config.y"
     {
 		      (ccval.stmt) = _cfg_find_keyword(block->stmt, (ccvsp[(1) - (1)].string));
 	      }
     break;
 
   case 22:
-#line 238 "config.y"
+#line 241 "config.y"
     {
 		      (ccval.value).type = CFG_STRING;
 		      (ccval.value).v.string = (ccvsp[(1) - (1)].string);
@@ -1570,7 +1573,7 @@ ccreduce:
     break;
 
   case 23:
-#line 243 "config.y"
+#line 246 "config.y"
     {
 		      (ccval.value).type = CFG_STRING;
 		      (ccval.value).v.string = (ccvsp[(1) - (1)].string);
@@ -1578,7 +1581,7 @@ ccreduce:
     break;
 
   case 24:
-#line 248 "config.y"
+#line 251 "config.y"
     {
 		      (ccval.value).type = CFG_INTEGER;
 		      (ccval.value).v.number = (ccvsp[(1) - (1)].number);
@@ -1586,7 +1589,7 @@ ccreduce:
     break;
 
   case 25:
-#line 253 "config.y"
+#line 256 "config.y"
     {
 		      (ccval.value).type = CFG_BOOLEAN;
 		      (ccval.value).v.bool = (ccvsp[(1) - (1)].bool);
@@ -1594,7 +1597,7 @@ ccreduce:
     break;
 
   case 26:
-#line 258 "config.y"
+#line 261 "config.y"
     {
 		      (ccval.value).type = CFG_CHAR;
 		      (ccval.value).v.ch = (ccvsp[(1) - (1)].number);
@@ -1602,7 +1605,7 @@ ccreduce:
     break;
 
   case 27:
-#line 263 "config.y"
+#line 266 "config.y"
     {
 		      (ccval.value).type = CFG_NETWORK;
 		      (ccval.value).v.network = (ccvsp[(1) - (1)].network);
@@ -1610,7 +1613,7 @@ ccreduce:
     break;
 
   case 28:
-#line 268 "config.y"
+#line 271 "config.y"
     {
 		      (ccval.value).type = CFG_HOST;
 		      (ccval.value).v.host.ipaddr = (ccvsp[(1) - (3)].ipaddr);
@@ -1619,7 +1622,7 @@ ccreduce:
     break;
 
   case 29:
-#line 276 "config.y"
+#line 279 "config.y"
     {
 		      (ccval.network).ipaddr = (ccvsp[(1) - (1)].ipaddr);
 		      (ccval.network).netmask = 0xffffffffL;
@@ -1627,7 +1630,7 @@ ccreduce:
     break;
 
   case 30:
-#line 281 "config.y"
+#line 284 "config.y"
     {
 		      (ccval.network).ipaddr = (ccvsp[(1) - (3)].ipaddr);
 		      (ccval.network).netmask = (ccvsp[(3) - (3)].ipaddr);
@@ -1635,7 +1638,7 @@ ccreduce:
     break;
 
   case 31:
-#line 288 "config.y"
+#line 291 "config.y"
     {
 		      if ((ccvsp[(1) - (1)].number) != '/')
 			      YYERROR;
@@ -1643,10 +1646,10 @@ ccreduce:
     break;
 
   case 33:
-#line 296 "config.y"
+#line 299 "config.y"
     {
 		      if ((ccvsp[(1) - (1)].number) > 32) {
-			      grad_log(L_ERR,
+			      grad_log(GRAD_LOG_ERR,
 				       _("invalid netmask length: %d"), (ccvsp[(1) - (1)].number));
 			      YYERROR;
 		      }
@@ -1656,7 +1659,7 @@ ccreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1660 "config.c"
+#line 1663 "config.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", ccr1[ccn], &ccval, &ccloc);
@@ -1870,7 +1873,7 @@ ccreturn:
 }
 
 
-#line 306 "config.y"
+#line 309 "config.y"
 
 
 static void
@@ -1990,7 +1993,7 @@ again:
                 do {
                         while (*curp != '*') {
                                 if (*curp == 0) {
-                                        grad_log(L_ERR, 
+                                        grad_log(GRAD_LOG_ERR, 
                        _("%s:%d: unexpected EOF in comment started at line %d"),
                                                  cfg_filename, 
                                                  cfg_line_num, 
@@ -2050,7 +2053,7 @@ again:
 static int
 ccerror(char *s)
 {
-        grad_log(L_ERR, "%s:%d: %s", cfg_filename, cfg_line_num, s);
+        grad_log(GRAD_LOG_ERR, "%s:%d: %s", cfg_filename, cfg_line_num, s);
 }
                 
 /* ************************************************************************* */
@@ -2208,7 +2211,7 @@ _get_value(cfg_value_t *arg, int type, void *base)
                           if (s) 
                                   value.v.number = ntohs(s->s_port);
                           else {
-                                  grad_log(L_ERR, 
+                                  grad_log(GRAD_LOG_ERR, 
                                            _("%s:%d: no such service: %s"),
                                            cfg_filename, cfg_line_num,
                                            value.v.string);
@@ -2234,7 +2237,7 @@ _get_value(cfg_value_t *arg, int type, void *base)
                 case CFG_STRING:
                         ipaddr = grad_ip_gethostaddr(value.v.string);
                         if (ipaddr == 0) {
-                                grad_log(L_ERR, 
+                                grad_log(GRAD_LOG_ERR, 
                                          _("%s:%d: unknown host: %s"),
                                          cfg_filename, cfg_line_num,
                                          value.v.string);
@@ -2255,6 +2258,16 @@ _get_value(cfg_value_t *arg, int type, void *base)
                 }
 		break;
 		
+	case CFG_UNSIGNED:
+	case CFG_SIZE_T:
+	case CFG_INTEGER:
+		switch (value.type) {
+		case CFG_UNSIGNED:
+		case CFG_SIZE_T:
+		case CFG_INTEGER:
+			value.type = type;
+			break;
+		} 
         }
         
         if (type != value.type) {
@@ -2292,7 +2305,7 @@ _get_value(cfg_value_t *arg, int type, void *base)
 		break;
 		
         default:
-                grad_log(L_CRIT,
+                grad_log(GRAD_LOG_CRIT,
                          _("INTERNAL ERROR at %s:%d: unknown datatype %d"),
                          __FILE__, __LINE__, type);
         }
@@ -2318,7 +2331,7 @@ cfg_malloc(size_t size,	void (*destructor)(void *))
 void
 cfg_type_error(int type)
 {
-	grad_log(L_ERR, 
+	grad_log(GRAD_LOG_ERR, 
 	         _("%s:%d: wrong datatype (should be %s)"),
 	         cfg_filename, cfg_line_num, typestr[type]);
 }
@@ -2326,7 +2339,7 @@ cfg_type_error(int type)
 void
 cfg_argc_error(int few)
 {
-	grad_log(L_ERR,
+	grad_log(GRAD_LOG_ERR,
 	         "%s:%d: %s",
 	         cfg_filename, cfg_line_num,
 	         few ? _("too few arguments") : _("too many arguments"));
@@ -2334,7 +2347,7 @@ cfg_argc_error(int few)
 
 #define _check_argc(argc, max) \
  if (argc-1 > max) {\
-     grad_log(L_ERR, "%s:%d: %s", \
+     grad_log(GRAD_LOG_ERR, "%s:%d: %s", \
               cfg_filename, cfg_line_num, _("too many arguments"));\
      return 0;\
  }		
@@ -2350,7 +2363,7 @@ int
 cfg_obsolete(int argc ARG_UNUSED, cfg_value_t *argv ARG_UNUSED,
 	     void *block_data ARG_UNUSED, void *handler_data ARG_UNUSED)
 {
-	grad_log(L_WARN, _("%s:%d: obsolete statement"),
+	grad_log(GRAD_LOG_WARN, _("%s:%d: obsolete statement"),
 	       cfg_filename, cfg_line_num);
 	return 0;
 }
@@ -2463,13 +2476,14 @@ cfg_read(char *fname, struct cfg_stmt *syntax, void *data)
         cfg_filename = fname;
 	_cfg_push_block(syntax, NULL, data);
         if (stat(cfg_filename, &st)) {
-                grad_log(L_ERR|L_PERROR, _("can't stat `%s'"), cfg_filename);
+                grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR, 
+                         _("can't stat `%s'"), cfg_filename);
                 return -1;
         }
         fd = open(cfg_filename, O_RDONLY);
         if (fd == -1) {
                 if (errno != ENOENT)
-                        grad_log(L_ERR|L_PERROR, 
+                        grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR, 
                                 _("can't open config file `%s'"), cfg_filename);
                 return -1;
         }
@@ -2480,7 +2494,7 @@ cfg_read(char *fname, struct cfg_stmt *syntax, void *data)
         close(fd);
         curp = buffer;
 
-        grad_log(L_INFO, _("reading %s"), cfg_filename);
+        grad_log(GRAD_LOG_INFO, _("reading %s"), cfg_filename);
         cfg_line_num = 1;
 
         if (strncmp(curp, "#debug", 6) == 0) {
