@@ -1,6 +1,6 @@
 /* This file is part of GNU Radius.
    Copyright (C) 2000,2001,2002,2003,2004,2006,
-   2007 Free Software Foundation, Inc.
+   2007,2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -104,7 +104,7 @@ validate_client(grad_request_t *radreq)
         CLIENT  *cl;
         
         if ((cl = client_lookup_ip(radreq->ipaddr)) == NULL) {
-                grad_log_req(L_ERR, radreq,
+                grad_log_req(GRAD_LOG_ERR, radreq,
 			     _("request from unknown client"));
                 return -1;
         }
@@ -155,22 +155,34 @@ radius_verify_digest(REQUEST *req)
 
 /* *********************** Radius Protocol Support ************************* */
 
+static void
+add_server_address(grad_request_t *req, const struct sockaddr_in *sa)
+{
+	grad_avl_add_pair(&req->avlist,
+			  grad_avp_create_integer(DA_GNU_SERVER_ADDRESS,
+						  ntohl(sa->sin_addr.s_addr)));
+	grad_avl_add_pair(&req->avlist,
+			  grad_avp_create_integer(DA_GNU_SERVER_PORT,
+						  ntohs(sa->sin_port)));
+}
+
 int
-radius_auth_req_decode(struct sockaddr_in *sa,
+radius_auth_req_decode(const struct sockaddr_in *srv_sa,
+		       const struct sockaddr_in *clt_sa,
 		       void *input, size_t inputsize, void **output)
 {
 	grad_request_t *greq;
         radiusd_request_t *radreq;
 
-	log_open(L_AUTH);
+	log_open(GRAD_LOG_AUTH);
 
         if (suspend_flag) {
-		stat_inc(auth, ntohl(sa->sin_addr.s_addr), num_dropped);
+		stat_inc(auth, ntohl(clt_sa->sin_addr.s_addr), num_dropped);
                 return 1;
 	}
         
-        greq = grad_decode_pdu(ntohl(sa->sin_addr.s_addr),
-			       ntohs(sa->sin_port),
+        greq = grad_decode_pdu(ntohl(clt_sa->sin_addr.s_addr),
+			       ntohs(clt_sa->sin_port),
 			       input,
 			       inputsize);
 	if (!greq)
@@ -183,6 +195,8 @@ radius_auth_req_decode(struct sockaddr_in *sa,
         }
 	
 	radreq = radiusd_request_alloc(greq);
+
+	add_server_address (radreq->request, srv_sa);
 	
 	/* RFC 2865 p. 2.2:
 	   The random challenge can either be included in the
@@ -203,20 +217,21 @@ radius_auth_req_decode(struct sockaddr_in *sa,
 }
 
 int
-radius_acct_req_decode(struct sockaddr_in *sa,
+radius_acct_req_decode(const struct sockaddr_in *srv_sa,
+		       const struct sockaddr_in *clt_sa,
 		       void *input, size_t inputsize, void **output)
 {
 	grad_request_t *greq;
 
-	log_open(L_ACCT);
+	log_open(GRAD_LOG_ACCT);
 	
         if (suspend_flag) {
-		stat_inc(acct, ntohl(sa->sin_addr.s_addr), num_dropped);
+		stat_inc(acct, ntohl(clt_sa->sin_addr.s_addr), num_dropped);
                 return 1;
 	}
         
-        greq = grad_decode_pdu(ntohl(sa->sin_addr.s_addr),
-			       ntohs(sa->sin_port),
+        greq = grad_decode_pdu(ntohl(clt_sa->sin_addr.s_addr),
+			       ntohs(clt_sa->sin_port),
 			       input,
 			       inputsize);
 	if (!greq)
@@ -228,7 +243,9 @@ radius_acct_req_decode(struct sockaddr_in *sa,
  		return 1;
         }
 
+	add_server_address (greq, srv_sa);
 	*output = radiusd_request_alloc(greq);
+	
 	return 0;
 }
 
@@ -408,7 +425,7 @@ radius_req_drop(int type, void *data, void *orig_data,
 {
 	radiusd_request_t *radreq = data ? data : orig_data;
 
-        grad_log_req(L_NOTICE, radreq->request,
+        grad_log_req(GRAD_LOG_NOTICE, radreq->request,
 		     "%s: %s", _("Dropping packet"),  status_str);
 
         switch (type) {
@@ -431,7 +448,7 @@ radius_req_xmit(REQUEST *request)
 		} else {
 			radius_send_reply(0, req,
 					  NULL, NULL, request->fd);
-			grad_log_req(L_NOTICE, req->request,
+			grad_log_req(GRAD_LOG_NOTICE, req->request,
 				     _("Retransmitting %s reply"),
 				     request_class[request->type].name);
 		} 
@@ -503,7 +520,8 @@ radius_respond(REQUEST *req)
 	case RT_ACCESS_CHALLENGE:
 		if (!req->orig) {
 			char buf[GRAD_MAX_SHORTNAME];
-			grad_log_req(L_PROXY|L_ERR, radreq->request,
+			grad_log_req(GRAD_LOG_PROXY|GRAD_LOG_ERR, 
+			             radreq->request,
 				     _("Unrecognized proxy reply from server %s, proxy ID %d"),
 				     client_lookup_name(radreq->request->ipaddr,
 						        buf, sizeof buf), 
@@ -537,7 +555,7 @@ radius_respond(REQUEST *req)
 
         default:
                 stat_inc(acct, radreq->request->ipaddr, num_unknowntypes);
-                grad_log_req(L_NOTICE, radreq->request,
+                grad_log_req(GRAD_LOG_NOTICE, radreq->request,
 			     _("unknown request code %d"), 
                              radreq->request->code); 
                 return -1;
@@ -638,6 +656,6 @@ radius_trace_path(radiusd_request_t *req)
 	td.file = NULL;
 	grad_list_iterate(req->locus_list, _trace_path_compose, &td);
 	p = obstack_finish(&td.stk);
-	grad_log_req(L_INFO, req->request, _("rule trace: %s"), p);
+	grad_log_req(GRAD_LOG_INFO, req->request, _("rule trace: %s"), p);
 	obstack_free(&td.stk, NULL);
 }
