@@ -1,5 +1,6 @@
 /* This file is part of GNU Radius.
-   Copyright (C) 2001,2002,2003,2004,2005,2007 Free Software Foundation, Inc.
+   Copyright (C) 2001,2002,2003,2004,2005,2007,
+   2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -199,7 +200,7 @@ scheme_redirect_output()
 						   scheme_outfile);
 		fd = open(filename, O_RDWR|O_CREAT|O_APPEND, 0600);
 		if (fd == -1) {
-			grad_log(L_ERR|L_PERROR,
+			grad_log(GRAD_LOG_ERR|GRAD_LOG_PERROR,
 			         _("can't open file `%s'"),
 			         filename);
 			fd = 2;
@@ -226,19 +227,17 @@ scheme_call_proc(SCM *result, char *procname, SCM arglist)
 	/* Evaluate the procedure */
 	procsym = RAD_SCM_SYMBOL_VALUE(procname);
 	if (scm_procedure_p(procsym) != SCM_BOOL_T) {
-		grad_log(L_ERR,
+		grad_log(GRAD_LOG_ERR,
 		         _("%s is not a procedure object"), procname);
 		return 1;
 	}
 	if (setjmp(jmp_env)) {
-		grad_log(L_NOTICE,
+		grad_log(GRAD_LOG_NOTICE,
 		         _("Procedure `%s' failed: see error output for details"),
 		         procname);
 		return 1;
 	}
-	SCM_NEWCELL(cell);
-	SCM_SETCAR(cell, procsym);
-	SCM_SETCDR(cell, arglist);
+	cell = scm_cons(procsym, arglist);
 	*result = scm_internal_lazy_catch(SCM_BOOL_T,
 					  eval_catch_body, cell,
 					  eval_catch_handler, &jmp_env);
@@ -268,6 +267,7 @@ catch_body(void *data)
 {
         SCM orig_load_path;
          
+        scheme_redirect_output();
 	scm_init_load_path();
 	grad_scm_init();
 	orig_load_path = RAD_SCM_SYMBOL_VALUE("%load-path");
@@ -332,18 +332,10 @@ scheme_try_auth(int auth_type, radiusd_request_t *req,
 
 	if (scheme_call_proc(&res,
 			     try_auth,
-			     SCM_LIST4(scm_listify(scm_copy_tree(SCM_IM_QUOTE),
-						   scm_long2num(auth_type),
-						   SCM_UNDEFINED),
-				       scm_listify(scm_copy_tree(SCM_IM_QUOTE),
-						   s_request,
-						   SCM_UNDEFINED),
-				       scm_listify(scm_copy_tree(SCM_IM_QUOTE),
-						   s_check,
-						   SCM_UNDEFINED),
-				       scm_listify(scm_copy_tree(SCM_IM_QUOTE),
-						   s_reply,
-						   SCM_UNDEFINED))))
+			     scm_list_4(scm_cons(SCM_IM_QUOTE, auth_type),
+					scm_cons(SCM_IM_QUOTE, s_request),
+					scm_cons(SCM_IM_QUOTE, s_check),
+					scm_cons(SCM_IM_QUOTE, s_reply))))
 		return 1;
 	
 	if (SCM_IMP(res) && SCM_BOOLP(res)) 
@@ -355,7 +347,7 @@ scheme_try_auth(int auth_type, radiusd_request_t *req,
 		grad_avl_free(list);
 		return code == SCM_BOOL_F;
 	}
-	grad_log(L_ERR,
+	grad_log(GRAD_LOG_ERR,
 	         _("Unexpected return value from Guile authentication function `%s'"),
 	         try_auth);
 	return 1;
@@ -379,15 +371,9 @@ scheme_auth(char *procname, radiusd_request_t *req,
 
 	if (scheme_call_proc(&res,
 			     procname,
-			     SCM_LIST3(scm_listify(scm_copy_tree(SCM_IM_QUOTE),
-						   s_request,
-						   SCM_UNDEFINED),
-				       scm_listify(scm_copy_tree(SCM_IM_QUOTE),
-						   s_check,
-						   SCM_UNDEFINED),
-				       scm_listify(scm_copy_tree(SCM_IM_QUOTE),
-						   s_reply,
-						   SCM_UNDEFINED))))
+			     scm_list_3(scm_cons(SCM_IM_QUOTE, s_request),
+					scm_cons(SCM_IM_QUOTE, s_check),
+					scm_cons(SCM_IM_QUOTE, s_reply))))
 		return 1;
 	
 	if (SCM_IMP(res) && SCM_BOOLP(res)) 
@@ -399,7 +385,7 @@ scheme_auth(char *procname, radiusd_request_t *req,
 		grad_avl_free(list);
 		return code == SCM_BOOL_F;
 	}
-	grad_log(L_ERR,
+	grad_log(GRAD_LOG_ERR,
 	         _("Unexpected return value from Guile authentication function `%s'"),
 	         procname);
 	return 1;
@@ -413,15 +399,13 @@ scheme_acct(char *procname, radiusd_request_t *req)
 
 	if (scheme_call_proc(&res,
 			     procname,
-			     SCM_LIST1(scm_listify(SCM_IM_QUOTE,
-						   s_request,
-						   SCM_UNDEFINED))))
+			     scm_list_1(scm_cons(SCM_IM_QUOTE, s_request))))
 		return 1;
 	
 	if (SCM_IMP(res) && SCM_BOOLP(res)) 
 		return res == SCM_BOOL_F;
 	else
-		grad_log(L_ERR,
+		grad_log(GRAD_LOG_ERR,
 		         _("Unexpected return value from Guile accounting function `%s'"),
 		         procname);
 
@@ -486,11 +470,10 @@ arglist_to_scm(int argc, cfg_value_t *argv)
 	
 	for (i = 1; i < argc; i++) {
                 SCM cell;
-		SCM_NEWCELL(cell);
 
 		switch (argv[i].type) {
 		case CFG_INTEGER:
-			val = scm_long2num(argv[i].v.number);
+			val = scm_from_long(argv[i].v.number);
 			break;
 			
 		case CFG_BOOLEAN:
@@ -515,12 +498,12 @@ arglist_to_scm(int argc, cfg_value_t *argv)
 				case 'x':
 					num = strtoul(p+1, &p, 16);
 					if (*p) {
-						grad_log(L_ERR,
+						grad_log(GRAD_LOG_ERR,
 							 _("Invalid hex number: %s"),
 							 argv[i].v.string);
 						return SCM_BOOL_F;
 					}
-					val = scm_long2num(num);
+					val = scm_from_long(num);
 				default:
 					val = scm_makfrom0str(p);
 				}
@@ -532,9 +515,8 @@ arglist_to_scm(int argc, cfg_value_t *argv)
 		break;
 
 		case CFG_NETWORK:
-			SCM_NEWCELL(val);
-			SCM_SETCAR(val, scm_ulong2num(argv[i].v.network.ipaddr));
-			SCM_SETCDR(val, scm_ulong2num(argv[i].v.network.netmask));
+			val = scm_cons(scm_from_ulong(argv[i].v.network.ipaddr),
+			               scm_from_ulong(argv[i].v.network.netmask));
 			break;
 			
 		case CFG_IPADDR:
@@ -547,12 +529,11 @@ arglist_to_scm(int argc, cfg_value_t *argv)
 			break;
 			
 		case CFG_HOST:
-			SCM_NEWCELL(val);
-			SCM_SETCAR(val, scm_long2num(argv[i].v.host.ipaddr));
-			SCM_SETCDR(val, scm_long2num(argv[i].v.host.port));
+			val = scm_cons(scm_from_long(argv[i].v.host.ipaddr),
+			               scm_from_long(argv[i].v.host.port));
 		}
-		
-		SCM_SETCAR(cell, scm_list_2(SCM_IM_QUOTE, val));
+
+		cell = scm_cons(scm_cons(SCM_IM_QUOTE, val), SCM_EOL);
 
 		if (head == SCM_EOL)
 			head = cell;
@@ -704,7 +685,7 @@ scheme_eval_avl (radiusd_request_t *request,
         grad_avp_t *p;
         
         if (!use_guile) {
-                grad_log_req(L_ERR, request->request,
+                grad_log_req(GRAD_LOG_ERR, request->request,
                              _("Guile authentication disabled in config"));
                 return -1;
         }
@@ -723,7 +704,7 @@ scheme_eval_avl (radiusd_request_t *request,
 
 	return rc;
 #else
-        grad_log_req(L_ERR, request->request,
+        grad_log_req(GRAD_LOG_ERR, request->request,
                      _("Guile authentication not available"));
         return -1;
 #endif
