@@ -1,6 +1,6 @@
 /* This file is part of GNU Radius.
    Copyright (C) 2000,2001,2002,2003,2004,2005,
-   2006,2007 Free Software Foundation, Inc.
+   2006,2007,2008 Free Software Foundation, Inc.
 
    Written by Sergey Poznyakoff
   
@@ -32,6 +32,7 @@
 
 #ifdef USE_SERVER_GUILE
 # include <libguile.h>
+# include <radscm.h>
 #endif
 
 #if defined(USE_SQL)
@@ -314,7 +315,7 @@ radiusd_sql_config()
         sqlfile = grad_mkfilename(grad_config_dir, "sqlserver");
         /* Open source file */
         if ((sqlfd = fopen(sqlfile, "r")) == (FILE *) NULL) {
-                grad_log(L_ERR, _("could not read sqlserver file %s"), sqlfile);
+                grad_log(GRAD_LOG_ERR, _("could not read sqlserver file %s"), sqlfile);
                 grad_free(sqlfile);
                 return -1;
         }
@@ -323,7 +324,7 @@ radiusd_sql_config()
         obstack_init(&parse_stack);
         while (get_conf_line()) {
                 if (stmt_type == -1) {
-                        grad_log(L_ERR,
+                        grad_log(GRAD_LOG_ERR,
                                  "%s:%d: %s",
                                  sqlfile, line_no,
 			         _("unrecognized keyword"));
@@ -331,7 +332,7 @@ radiusd_sql_config()
                 }
                 /* Each keyword should have an argument */
                 if (cur_ptr == NULL) {
-                        grad_log(L_ERR,
+                        grad_log(GRAD_LOG_ERR,
                                  "%s:%d: %s",
                                  sqlfile, line_no,
 			         _("required argument missing"));
@@ -342,7 +343,7 @@ radiusd_sql_config()
                 case STMT_SERVER:
                        	if (cur_ptr[0] != '/'
 			    && !grad_ip_gethostaddr(cur_ptr)) {
-                                grad_log(L_ERR,
+                                grad_log(GRAD_LOG_ERR,
                                          _("%s:%d: unknown host: %s"),
                                          sqlfile, line_no,
                                          cur_ptr);
@@ -356,7 +357,7 @@ radiusd_sql_config()
                 case STMT_PORT:
                         new_cfg.port = strtol(cur_ptr, &ptr, 0);
                         if (*ptr != 0 && !isspace(*ptr)) {
-                                grad_log(L_ERR,
+                                grad_log(GRAD_LOG_ERR,
 				         "%s:%d: %s",
                                          sqlfile, line_no,
 				         _("number parse error"));
@@ -375,7 +376,7 @@ radiusd_sql_config()
                         
                 case STMT_KEEPOPEN:
                         if (get_boolean(cur_ptr, &new_cfg.keepopen))
-                                grad_log(L_ERR,
+                                grad_log(GRAD_LOG_ERR,
                                          "%s:%d: %s",
                                          sqlfile, line_no,
 				         _("expected boolean value"));
@@ -384,7 +385,7 @@ radiusd_sql_config()
                 case STMT_IDLE_TIMEOUT:
                         timeout = strtol(cur_ptr, &ptr, 0);
                         if ((*ptr != 0 && !isspace(*ptr)) || timeout <= 0) {
-                                grad_log(L_ERR, "%s:%d: %s",
+                                grad_log(GRAD_LOG_ERR, "%s:%d: %s",
                                          sqlfile, line_no,
 				         _("number parse error"));
                         } else 
@@ -393,7 +394,7 @@ radiusd_sql_config()
                         
                 case STMT_DOAUTH:       
                         if (get_boolean(cur_ptr, &new_cfg.active[SQL_AUTH]))
-                                grad_log(L_ERR,
+                                grad_log(GRAD_LOG_ERR,
                                          "%s:%d: %s",
                                          sqlfile, line_no,
 				         _("expected boolean value"));
@@ -401,7 +402,7 @@ radiusd_sql_config()
                         
                 case STMT_DOACCT:
                         if (get_boolean(cur_ptr, &new_cfg.active[SQL_ACCT]))
-                                grad_log(L_ERR,
+                                grad_log(GRAD_LOG_ERR,
                                          "%s:%d: %s", 
                                          sqlfile, line_no,
 				         _("expected boolean value"));
@@ -416,21 +417,21 @@ radiusd_sql_config()
                         break;
                         
                 case STMT_MAX_AUTH_CONNECTIONS:
-                        grad_log(L_WARN,
+                        grad_log(GRAD_LOG_WARN,
                                  "%s:%d: %s",
                                  sqlfile, line_no,
 			         _("auth_max_connections is obsolete"));
                         break;
                         
                 case STMT_MAX_ACCT_CONNECTIONS:
-                        grad_log(L_WARN,
+                        grad_log(GRAD_LOG_WARN,
                                  "%s:%d: %s",
                                  sqlfile, line_no,
 			         _("acct_max_connections is obsolete"));
                         break;
                         
                 case STMT_QUERY_BUFFER_SIZE:
-                        grad_log(L_WARN,
+                        grad_log(GRAD_LOG_WARN,
 			         "%s:%d: %s",
 			         sqlfile, line_no,
 			         _("query_buffer_size is obsolete"));
@@ -439,7 +440,7 @@ radiusd_sql_config()
                 case STMT_INTERFACE:
                         new_cfg.interface = disp_sql_interface_index(cur_ptr);
                         if (!new_cfg.interface) {
-                                grad_log(L_WARN, "%s:%d: %s",
+                                grad_log(GRAD_LOG_WARN, "%s:%d: %s",
                                          sqlfile, line_no,
 				         _("Unsupported SQL interface"));
                         }
@@ -514,23 +515,23 @@ sql_check_config(const char *filename, SQL_cfg *cfg)
 	/* Check general SQL setup */
 	if (cfg->active[SQL_AUTH] || cfg->active[SQL_ACCT]) {
 		if (disp_sql_interface_index(NULL) == 0) {
-			grad_log(L_ERR, _("%s: SQL interface not specified"),
+			grad_log(GRAD_LOG_ERR, _("%s: SQL interface not specified"),
 				 filename);
 			doacct = doauth = 0;
 		}
 
 		if (!cfg->server) {
-			missing_statement(L_ERR, filename, "server");
+			missing_statement(GRAD_LOG_ERR, filename, "server");
 			doacct = doauth = 0;
 		}
 
 		if (!cfg->login) {
-			missing_statement(L_ERR, filename, "login");
+			missing_statement(GRAD_LOG_ERR, filename, "login");
 			doacct = doauth = 0;
 		}
 
 		if (!cfg->password) {
-			missing_statement(L_ERR, filename, "password");
+			missing_statement(GRAD_LOG_ERR, filename, "password");
 			doacct = doauth = 0;
 		}
 	}
@@ -538,60 +539,60 @@ sql_check_config(const char *filename, SQL_cfg *cfg)
 	/* Check SQL authentication setup */
         if (cfg->active[SQL_AUTH]) {
 		if (!cfg->auth_db) {
-			missing_statement(L_ERR, filename, "auth_db");
+			missing_statement(GRAD_LOG_ERR, filename, "auth_db");
 			doauth = 0;
 		}
 
 		FREE_IF_EMPTY(cfg->query[auth_query]);
 		if (!cfg->query[auth_query]) {
-			missing_statement(L_ERR, filename, "auth_query");
+			missing_statement(GRAD_LOG_ERR, filename, "auth_query");
 			doauth = 0;
 		}
 			 
 		if (!cfg->query[group_query]) 
-			missing_statement(L_WARN, filename, "group_query");
+			missing_statement(GRAD_LOG_WARN, filename, "group_query");
                 FREE_IF_EMPTY(cfg->query[group_query]);
         }
 
 	/* Check SQL accounting setup */
         if (cfg->active[SQL_ACCT]) {
 		if (!cfg->acct_db) {
-			missing_statement(L_ERR, filename, "acct_db");
+			missing_statement(GRAD_LOG_ERR, filename, "acct_db");
 			doacct = 0;
 		}
                 if (!cfg->query[acct_start_query]) 
-			missing_statement(L_WARN, filename,
+			missing_statement(GRAD_LOG_WARN, filename,
 					  "acct_start_query");
                 FREE_IF_EMPTY(cfg->query[acct_start_query]);
 
 		if (!cfg->query[acct_stop_query]) {
-			missing_statement(L_ERR, filename, "acct_stop_query");
+			missing_statement(GRAD_LOG_ERR, filename, "acct_stop_query");
 			doacct = 0;
 		}
 		FREE_IF_EMPTY(cfg->query[acct_stop_query]);
 
                 if (!cfg->query[acct_nasdown_query]) 
-			missing_statement(L_WARN, filename,
+			missing_statement(GRAD_LOG_WARN, filename,
 					  "acct_nasdown_query");
                 FREE_IF_EMPTY(cfg->query[acct_nasdown_query]);
 
                 if (!cfg->query[acct_nasup_query])
-			missing_statement(L_WARN, filename,
+			missing_statement(GRAD_LOG_WARN, filename,
 					  "acct_nasup_query");
                 FREE_IF_EMPTY(cfg->query[acct_nasup_query]);
         }
 
 	/* Inform the user */
 	if (cfg->active[SQL_AUTH] != doauth)
-		grad_log(L_NOTICE, _("disabling SQL authentication"));
+		grad_log(GRAD_LOG_NOTICE, _("disabling SQL authentication"));
 	if (cfg->active[SQL_ACCT] != doacct)
-		grad_log(L_NOTICE, _("disabling SQL accounting"));
+		grad_log(GRAD_LOG_NOTICE, _("disabling SQL accounting"));
 }
 
 void
 sql_flush()
 {
-        grad_log(L_NOTICE,
+        grad_log(GRAD_LOG_NOTICE,
                  _("SQL configuration changed: closing existing connections"));
         radiusd_flush_queue();
 	radiusd_sql_shutdown();
@@ -812,7 +813,7 @@ radiusd_sql_acct(radiusd_request_t *radreq)
         if (!(pair = grad_avl_find(radreq->request->avlist,
 				   DA_ACCT_STATUS_TYPE))) {
                 /* should never happen!! */
-                grad_log_req(L_ERR, radreq->request,
+                grad_log_req(GRAD_LOG_ERR, radreq->request,
                              _("no Acct-Status-Type attribute in rad_sql_acct()"));
                 return;
         }
@@ -844,7 +845,7 @@ radiusd_sql_acct(radiusd_request_t *radreq)
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
                 if (rc == 0 && count != 1) 
-			log_facility = L_WARN;
+			log_facility = GRAD_LOG_WARN;
                 break;
 
         case DV_ACCT_STATUS_TYPE_ACCOUNTING_ON:
@@ -857,7 +858,7 @@ radiusd_sql_acct(radiusd_request_t *radreq)
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
 		if (rc == 0)
-			log_facility = L_INFO;
+			log_facility = GRAD_LOG_INFO;
                 break;
 
         case DV_ACCT_STATUS_TYPE_ACCOUNTING_OFF:
@@ -870,7 +871,7 @@ radiusd_sql_acct(radiusd_request_t *radreq)
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
 		if (rc == 0)
-			log_facility = L_INFO;
+			log_facility = GRAD_LOG_INFO;
                 break;
 
         case DV_ACCT_STATUS_TYPE_ALIVE:
@@ -883,7 +884,7 @@ radiusd_sql_acct(radiusd_request_t *radreq)
                 rc = disp_sql_query(conn, query, &count);
                 sqllog(rc, query);
                 if (rc == 0 && count != 1) 
-			log_facility = L_WARN;
+			log_facility = GRAD_LOG_WARN;
                 break;
                 
         }
@@ -910,7 +911,7 @@ radiusd_sql_pass(radiusd_request_t *req, char *authdata)
         struct obstack stack;
         
         if (sql_cfg.active[SQL_AUTH] == 0) {
-                grad_log(L_ERR,
+                grad_log(GRAD_LOG_ERR,
                          _("SQL Auth specified in users file, but not in sqlserver file"));
                 return NULL;
         }
@@ -1009,7 +1010,7 @@ rad_sql_retrieve_pairs(struct sql_connection *conn,
 			char *opstr = res->tuple[i][2];
                         op = grad_str_to_op(opstr);
                         if (op == grad_operator_invalid) {
-                                grad_log(L_NOTICE,
+                                grad_log(GRAD_LOG_NOTICE,
                                          _("SQL: invalid operator: %s"), opstr);
                                 continue;
                         }
@@ -1220,6 +1221,9 @@ rad_sql_mlc_close(struct radutmp *up)
 	grad_avl_add_pair(&req->avlist,
 			  grad_avp_create_integer(DA_NAS_PORT_ID,
 						  up->nas_port));
+	grad_avl_add_pair(&req->avlist,
+			  grad_avp_create_integer(DA_NAS_IP_ADDRESS,
+						  ntohl(up->nas_address)));
 	grad_avl_add_pair(&req->avlist,
 			  grad_avp_create_string(DA_ACCT_SESSION_ID,
 						 up->session_id));
@@ -1228,7 +1232,7 @@ rad_sql_mlc_close(struct radutmp *up)
 	rc = disp_sql_query(conn, query, &count);
 	sqllog(rc, query);
 	if (rc == 0 && count != 1) {
-		grad_log(L_WARN,
+		grad_log(GRAD_LOG_WARN,
 			 ngettext("%s updated %d record",
 				  "%s updated %d records",
 				  count),
@@ -1257,7 +1261,7 @@ sql_init()
 #ifdef USE_SERVER_GUILE
 
 SCM
-sql_exec_query(int type, char *query)
+sql_exec_query(int type, const char *query)
 {
 	int i, j;
         struct sql_connection *conn;
@@ -1277,36 +1281,27 @@ sql_exec_query(int type, char *query)
 		SCM head = SCM_EOL, tail;
 		
 		for (j = 0; tuple = disp_sql_column(conn, data, j); j++) {
-			SCM new_elt;
-			SCM_NEWCELL(new_elt);
-			SCM_SETCAR(new_elt, scm_makfrom0str(tuple));
+			SCM new_elt = scm_cons(scm_makfrom0str(tuple), SCM_EOL);
 			if (head == SCM_EOL)
 				head = new_elt;
 			else
 				SCM_SETCDR(tail, new_elt);
 			tail = new_elt;
 		}
-		if (head != SCM_EOL)
-			SCM_SETCDR(tail, SCM_EOL);
-		SCM_NEWCELL(new_row);
-		SCM_SETCAR(new_row, head);
-
+		new_row = scm_cons(head, SCM_EOL);
 		if (row_head == SCM_EOL)
 			row_head = new_row;
 		else
 			SCM_SETCDR(row_tail, new_row);
 		row_tail = new_row;
 	}
-	if (row_head != SCM_EOL)
-		SCM_SETCDR(row_tail, SCM_EOL);
-
 	disp_sql_free(conn, data);
 	
 	return row_head;
 }
 
 SCM
-sql_run_query(int type, char *query)
+sql_run_query(int type, const char *query)
 {
 	int rc;
         struct sql_connection *conn;
@@ -1319,7 +1314,7 @@ sql_run_query(int type, char *query)
 	rc = disp_sql_query(conn, query, &count);
 	if (rc)
                 return SCM_BOOL_F;
-	return scm_long2num(count);
+	return scm_from_long(count);
 }
 #endif
 
